@@ -1,12 +1,12 @@
-makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = FALSE) {
+makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = NULL) {
   names <- paste("Fold", 1:nfolds)
   runs <- sapply(names, function(x) NULL)
-  if (seed)  set.seed(1234)
+  if ( !is.null(seed) )  set.seed(seed)
 
   if ( !stratified ) {
     oop <- options(warn = -1)
     rat <- length(ina) %% nfolds
-    mat <- matrix( sample( length(ina) ), ncol = nfolds )
+    mat <- matrix( Rfast2::Sample.int( length(ina), length(ina) ), ncol = nfolds )
     mat[-c( 1:length(ina) )] <- NA
     on.exit(options(oop))
     for ( i in 1:c(nfolds - 1) )  runs[[ i ]] <- mat[, i]
